DialogflowAuth class abstract

Contains the necessary CallOptions needed to connect to a Dialogflow Server.

Implementers

Constructors

DialogflowAuth()

Properties

callOptions → CallOptions
Returns the CallOptions of the created service account. These can then be used to initialize a new SessionClient.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

scopes → List<String>
Scopes that are needed to use the Dialogflow API
final
session ↔ String
getter/setter pair