AgentsServiceBase class abstract

Constructors

AgentsServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
deleteAgent(ServiceCall call, DeleteAgentRequest request) → Future<Empty>
deleteAgent_Pre(ServiceCall call, Future<DeleteAgentRequest> request) → Future<Empty>
exportAgent(ServiceCall call, ExportAgentRequest request) → Future<Operation>
exportAgent_Pre(ServiceCall call, Future<ExportAgentRequest> request) → Future<Operation>
getAgent(ServiceCall call, GetAgentRequest request) → Future<Agent>
getAgent_Pre(ServiceCall call, Future<GetAgentRequest> request) → Future<Agent>
getValidationResult(ServiceCall call, GetValidationResultRequest request) → Future<ValidationResult>
getValidationResult_Pre(ServiceCall call, Future<GetValidationResultRequest> request) → Future<ValidationResult>
importAgent(ServiceCall call, ImportAgentRequest request) → Future<Operation>
importAgent_Pre(ServiceCall call, Future<ImportAgentRequest> request) → Future<Operation>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restoreAgent(ServiceCall call, RestoreAgentRequest request) → Future<Operation>
restoreAgent_Pre(ServiceCall call, Future<RestoreAgentRequest> request) → Future<Operation>
searchAgents(ServiceCall call, SearchAgentsRequest request) → Future<SearchAgentsResponse>
searchAgents_Pre(ServiceCall call, Future<SearchAgentsRequest> request) → Future<SearchAgentsResponse>
setAgent(ServiceCall call, SetAgentRequest request) → Future<Agent>
setAgent_Pre(ServiceCall call, Future<SetAgentRequest> request) → Future<Agent>
toString() → String
A string representation of this object.
inherited
trainAgent(ServiceCall call, TrainAgentRequest request) → Future<Operation>
trainAgent_Pre(ServiceCall call, Future<TrainAgentRequest> request) → Future<Operation>

Operators

operator ==(Object other) → bool
The equality operator.
inherited