ContextsServiceBase class abstract

Constructors

ContextsServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
createContext(ServiceCall call, CreateContextRequest request) → Future<Context>
createContext_Pre(ServiceCall call, Future<CreateContextRequest> request) → Future<Context>
deleteAllContexts(ServiceCall call, DeleteAllContextsRequest request) → Future<Empty>
deleteAllContexts_Pre(ServiceCall call, Future<DeleteAllContextsRequest> request) → Future<Empty>
deleteContext(ServiceCall call, DeleteContextRequest request) → Future<Empty>
deleteContext_Pre(ServiceCall call, Future<DeleteContextRequest> request) → Future<Empty>
getContext(ServiceCall call, GetContextRequest request) → Future<Context>
getContext_Pre(ServiceCall call, Future<GetContextRequest> request) → Future<Context>
listContexts(ServiceCall call, ListContextsRequest request) → Future<ListContextsResponse>
listContexts_Pre(ServiceCall call, Future<ListContextsRequest> request) → Future<ListContextsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateContext(ServiceCall call, UpdateContextRequest request) → Future<Context>
updateContext_Pre(ServiceCall call, Future<UpdateContextRequest> request) → Future<Context>

Operators

operator ==(Object other) → bool
The equality operator.
inherited