createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
CreateConversationRequest createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
CreateConversationRequest createEmptyInstance() => create();