IntentsServiceBase class abstract

Constructors

IntentsServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
batchDeleteIntents(ServiceCall call, BatchDeleteIntentsRequest request) → Future<Operation>
batchDeleteIntents_Pre(ServiceCall call, Future<BatchDeleteIntentsRequest> request) → Future<Operation>
batchUpdateIntents(ServiceCall call, BatchUpdateIntentsRequest request) → Future<Operation>
batchUpdateIntents_Pre(ServiceCall call, Future<BatchUpdateIntentsRequest> request) → Future<Operation>
createIntent(ServiceCall call, CreateIntentRequest request) → Future<Intent>
createIntent_Pre(ServiceCall call, Future<CreateIntentRequest> request) → Future<Intent>
deleteIntent(ServiceCall call, DeleteIntentRequest request) → Future<Empty>
deleteIntent_Pre(ServiceCall call, Future<DeleteIntentRequest> request) → Future<Empty>
getIntent(ServiceCall call, GetIntentRequest request) → Future<Intent>
getIntent_Pre(ServiceCall call, Future<GetIntentRequest> request) → Future<Intent>
listIntents(ServiceCall call, ListIntentsRequest request) → Future<ListIntentsResponse>
listIntents_Pre(ServiceCall call, Future<ListIntentsRequest> request) → Future<ListIntentsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateIntent(ServiceCall call, UpdateIntentRequest request) → Future<Intent>
updateIntent_Pre(ServiceCall call, Future<UpdateIntentRequest> request) → Future<Intent>

Operators

operator ==(Object other) → bool
The equality operator.
inherited