SessionsServiceBase class abstract

Constructors

SessionsServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
detectIntent(ServiceCall call, DetectIntentRequest request) → Future<DetectIntentResponse>
detectIntent_Pre(ServiceCall call, Future<DetectIntentRequest> request) → Future<DetectIntentResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
streamingDetectIntent(ServiceCall call, Stream<StreamingDetectIntentRequest> request) → Stream<StreamingDetectIntentResponse>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited