LoggingServiceV2ServiceBase class abstract

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
deleteLog(ServiceCall call, DeleteLogRequest request) → Future<Empty>
deleteLog_Pre(ServiceCall call, Future<DeleteLogRequest> request) → Future<Empty>
listLogEntries(ServiceCall call, ListLogEntriesRequest request) → Future<ListLogEntriesResponse>
listLogEntries_Pre(ServiceCall call, Future<ListLogEntriesRequest> request) → Future<ListLogEntriesResponse>
listLogs(ServiceCall call, ListLogsRequest request) → Future<ListLogsResponse>
listLogs_Pre(ServiceCall call, Future<ListLogsRequest> request) → Future<ListLogsResponse>
listMonitoredResourceDescriptors(ServiceCall call, ListMonitoredResourceDescriptorsRequest request) → Future<ListMonitoredResourceDescriptorsResponse>
listMonitoredResourceDescriptors_Pre(ServiceCall call, Future<ListMonitoredResourceDescriptorsRequest> request) → Future<ListMonitoredResourceDescriptorsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tailLogEntries(ServiceCall call, Stream<TailLogEntriesRequest> request) → Stream<TailLogEntriesResponse>
toString() → String
A string representation of this object.
inherited
writeLogEntries(ServiceCall call, WriteLogEntriesRequest request) → Future<WriteLogEntriesResponse>
writeLogEntries_Pre(ServiceCall call, Future<WriteLogEntriesRequest> request) → Future<WriteLogEntriesResponse>

Operators

operator ==(Object other) → bool
The equality operator.
inherited