TestExtremeDefaultValues class

Inheritance
  • Object
  • GeneratedMessage
  • TestExtremeDefaultValues

Constructors

TestExtremeDefaultValues({List<int>? escapedBytes, int? largeUint32, Int64? largeUint64, int? smallInt32, Int64? smallInt64, String? utf8String, double? zeroFloat, double? oneFloat, double? smallFloat, double? negativeOneFloat, double? negativeFloat, double? largeFloat, double? smallNegativeFloat, double? infDouble, double? negInfDouble, double? nanDouble, double? infFloat, double? negInfFloat, double? nanFloat, String? cppTrigraph, int? reallySmallInt32, Int64? reallySmallInt64, String? stringWithZero, List<int>? bytesWithZero, String? stringPieceWithZero, String? cordWithZero, String? replacementString})
factory
TestExtremeDefaultValues.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
TestExtremeDefaultValues.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

bytesWithZero ↔ List<int>
getter/setter pair
cordWithZero ↔ String
getter/setter pair
cppTrigraph ↔ String
getter/setter pair
escapedBytes ↔ List<int>
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
infDouble ↔ double
getter/setter pair
infFloat ↔ double
getter/setter pair
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
largeFloat ↔ double
getter/setter pair
largeUint32 ↔ int
getter/setter pair
largeUint64 ↔ Int64
getter/setter pair
nanDouble ↔ double
getter/setter pair
nanFloat ↔ double
getter/setter pair
negativeFloat ↔ double
getter/setter pair
negativeOneFloat ↔ double
getter/setter pair
negInfDouble ↔ double
getter/setter pair
negInfFloat ↔ double
getter/setter pair
oneFloat ↔ double
getter/setter pair
reallySmallInt32 ↔ int
getter/setter pair
reallySmallInt64 ↔ Int64
getter/setter pair
replacementString ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smallFloat ↔ double
getter/setter pair
smallInt32 ↔ int
getter/setter pair
smallInt64 ↔ Int64
getter/setter pair
smallNegativeFloat ↔ double
getter/setter pair
stringPieceWithZero ↔ String
getter/setter pair
stringWithZero ↔ String
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
utf8String ↔ String
getter/setter pair
zeroFloat ↔ double
getter/setter pair

Methods

$_ensure<T>(int index) → T
For generated code only.
inherited
$_get<T>(int index, T defaultValue) → T
For generated code only.
inherited
$_getB(int index, bool defaultValue) → bool
For generated code only.
inherited
$_getBF(int index) → bool
For generated code only.
inherited
$_getI(int index, int defaultValue) → int
For generated code only.
inherited
$_getI64(int index) → Int64
For generated code only.
inherited
$_getIZ(int index) → int
For generated code only.
inherited
$_getList<T>(int index) → List<T>
For generated code only.
inherited
$_getMap<K, V>(int index) → Map<K, V>
For generated code only.
inherited
$_getN<T>(int index) → T
For generated code only.
inherited
$_getS(int index, String defaultValue) → String
For generated code only.
inherited
$_getSZ(int index) → String
For generated code only.
inherited
$_has(int index) → bool
For generated code only.
inherited
$_setBool(int index, bool value) → void
For generated code only.
inherited
$_setBytes(int index, List<int> value) → void
For generated code only.
inherited
$_setDouble(int index, double value) → void
For generated code only.
inherited
$_setFloat(int index, double value) → void
For generated code only.
inherited
$_setInt64(int index, Int64 value) → void
For generated code only.
inherited
$_setSignedInt32(int index, int value) → void
For generated code only.
inherited
$_setString(int index, String value) → void
For generated code only.
inherited
$_setUnsignedInt32(int index, int value) → void
For generated code only.
inherited
$_whichOneof(int oneofIndex) → int
inherited
addExtension(Extension extension, dynamic value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBytesWithZero() → void
clearCordWithZero() → void
clearCppTrigraph() → void
clearEscapedBytes() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearInfDouble() → void
clearInfFloat() → void
clearLargeFloat() → void
clearLargeUint32() → void
clearLargeUint64() → void
clearNanDouble() → void
clearNanFloat() → void
clearNegativeFloat() → void
clearNegativeOneFloat() → void
clearNegInfDouble() → void
clearNegInfFloat() → void
clearOneFloat() → void
clearReallySmallInt32() → void
clearReallySmallInt64() → void
clearReplacementString() → void
clearSmallFloat() → void
clearSmallInt32() → void
clearSmallInt64() → void
clearSmallNegativeFloat() → void
clearStringPieceWithZero() → void
clearStringWithZero() → void
clearUtf8String() → void
clearZeroFloat() → void
clone() → TestExtremeDefaultValues
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(TestExtremeDefaultValues)) → TestExtremeDefaultValues
Apply updates to a copy of this message.
override
createEmptyInstance() → TestExtremeDefaultValues
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasBytesWithZero() → bool
hasCordWithZero() → bool
hasCppTrigraph() → bool
hasEscapedBytes() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasInfDouble() → bool
hasInfFloat() → bool
hasLargeFloat() → bool
hasLargeUint32() → bool
hasLargeUint64() → bool
hasNanDouble() → bool
hasNanFloat() → bool
hasNegativeFloat() → bool
hasNegativeOneFloat() → bool
hasNegInfDouble() → bool
hasNegInfFloat() → bool
hasOneFloat() → bool
hasReallySmallInt32() → bool
hasReallySmallInt64() → bool
hasReplacementString() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
hasSmallFloat() → bool
hasSmallInt32() → bool
hasSmallInt64() → bool
hasSmallNegativeFloat() → bool
hasStringPieceWithZero() → bool
hasStringWithZero() → bool
hasUtf8String() → bool
hasZeroFloat() → bool
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited