TestOneof2 class

Inheritance
  • Object
  • GeneratedMessage
  • TestOneof2

Constructors

TestOneof2({int? fooInt, String? fooString, String? fooCord, String? fooStringPiece, List<int>? fooBytes, TestOneof2_NestedEnum? fooEnum, TestOneof2_NestedMessage? fooMessage, TestOneof2_FooGroup? fooGroup, TestOneof2_NestedMessage? fooLazyMessage, int? barInt, String? barString, String? barCord, String? barStringPiece, List<int>? barBytes, TestOneof2_NestedEnum? barEnum, int? bazInt, String? bazString})
factory
TestOneof2.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
TestOneof2.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

barBytes ↔ List<int>
getter/setter pair
barCord ↔ String
getter/setter pair
barEnum ↔ TestOneof2_NestedEnum
getter/setter pair
barInt ↔ int
getter/setter pair
barString ↔ String
getter/setter pair
barStringPiece ↔ String
getter/setter pair
bazInt ↔ int
getter/setter pair
bazString ↔ String
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
fooBytes ↔ List<int>
getter/setter pair
fooCord ↔ String
getter/setter pair
fooEnum ↔ TestOneof2_NestedEnum
getter/setter pair
fooGroup ↔ TestOneof2_FooGroup
getter/setter pair
fooInt ↔ int
getter/setter pair
fooLazyMessage ↔ TestOneof2_NestedMessage
getter/setter pair
fooMessage ↔ TestOneof2_NestedMessage
getter/setter pair
fooString ↔ String
getter/setter pair
fooStringPiece ↔ String
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownFields → UnknownFieldSet
no setterinherited

Methods

$_ensure<T>(int index) → T
For generated code only.
inherited
$_get<T>(int index, T defaultValue) → T
For generated code only.
inherited
$_getB(int index, bool defaultValue) → bool
For generated code only.
inherited
$_getBF(int index) → bool
For generated code only.
inherited
$_getI(int index, int defaultValue) → int
For generated code only.
inherited
$_getI64(int index) → Int64
For generated code only.
inherited
$_getIZ(int index) → int
For generated code only.
inherited
$_getList<T>(int index) → List<T>
For generated code only.
inherited
$_getMap<K, V>(int index) → Map<K, V>
For generated code only.
inherited
$_getN<T>(int index) → T
For generated code only.
inherited
$_getS(int index, String defaultValue) → String
For generated code only.
inherited
$_getSZ(int index) → String
For generated code only.
inherited
$_has(int index) → bool
For generated code only.
inherited
$_setBool(int index, bool value) → void
For generated code only.
inherited
$_setBytes(int index, List<int> value) → void
For generated code only.
inherited
$_setDouble(int index, double value) → void
For generated code only.
inherited
$_setFloat(int index, double value) → void
For generated code only.
inherited
$_setInt64(int index, Int64 value) → void
For generated code only.
inherited
$_setSignedInt32(int index, int value) → void
For generated code only.
inherited
$_setString(int index, String value) → void
For generated code only.
inherited
$_setUnsignedInt32(int index, int value) → void
For generated code only.
inherited
$_whichOneof(int oneofIndex) → int
inherited
addExtension(Extension extension, dynamic value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBar() → void
clearBarBytes() → void
clearBarCord() → void
clearBarEnum() → void
clearBarInt() → void
clearBarString() → void
clearBarStringPiece() → void
clearBazInt() → void
clearBazString() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFoo() → void
clearFooBytes() → void
clearFooCord() → void
clearFooEnum() → void
clearFooGroup() → void
clearFooInt() → void
clearFooLazyMessage() → void
clearFooMessage() → void
clearFooString() → void
clearFooStringPiece() → void
clone() → TestOneof2
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(TestOneof2)) → TestOneof2
Apply updates to a copy of this message.
override
createEmptyInstance() → TestOneof2
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
ensureFooLazyMessage() → TestOneof2_NestedMessage
ensureFooMessage() → TestOneof2_NestedMessage
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasBarBytes() → bool
hasBarCord() → bool
hasBarEnum() → bool
hasBarInt() → bool
hasBarString() → bool
hasBarStringPiece() → bool
hasBazInt() → bool
hasBazString() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasFooBytes() → bool
hasFooCord() → bool
hasFooEnum() → bool
hasFooGroup() → bool
hasFooInt() → bool
hasFooLazyMessage() → bool
hasFooMessage() → bool
hasFooString() → bool
hasFooStringPiece() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
whichBar() → TestOneof2_Bar
whichFoo() → TestOneof2_Foo
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create() → TestOneof2
createRepeated() → PbList<TestOneof2>
getDefault() → TestOneof2