TestRequired class

Inheritance
  • Object
  • GeneratedMessage
  • TestRequired

Constructors

TestRequired({int? a, int? dummy2, int? b, int? dummy4, int? dummy5, int? dummy6, int? dummy7, int? dummy8, int? dummy9, int? dummy10, int? dummy11, int? dummy12, int? dummy13, int? dummy14, int? dummy15, int? dummy16, int? dummy17, int? dummy18, int? dummy19, int? dummy20, int? dummy21, int? dummy22, int? dummy23, int? dummy24, int? dummy25, int? dummy26, int? dummy27, int? dummy28, int? dummy29, int? dummy30, int? dummy31, int? dummy32, int? c})
factory
TestRequired.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
TestRequired.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

a ↔ int
getter/setter pair
b ↔ int
getter/setter pair
c ↔ int
getter/setter pair
dummy10 ↔ int
getter/setter pair
dummy11 ↔ int
getter/setter pair
dummy12 ↔ int
getter/setter pair
dummy13 ↔ int
getter/setter pair
dummy14 ↔ int
getter/setter pair
dummy15 ↔ int
getter/setter pair
dummy16 ↔ int
getter/setter pair
dummy17 ↔ int
getter/setter pair
dummy18 ↔ int
getter/setter pair
dummy19 ↔ int
getter/setter pair
dummy2 ↔ int
getter/setter pair
dummy20 ↔ int
getter/setter pair
dummy21 ↔ int
getter/setter pair
dummy22 ↔ int
getter/setter pair
dummy23 ↔ int
getter/setter pair
dummy24 ↔ int
getter/setter pair
dummy25 ↔ int
getter/setter pair
dummy26 ↔ int
getter/setter pair
dummy27 ↔ int
getter/setter pair
dummy28 ↔ int
getter/setter pair
dummy29 ↔ int
getter/setter pair
dummy30 ↔ int
getter/setter pair
dummy31 ↔ int
getter/setter pair
dummy32 ↔ int
getter/setter pair
dummy4 ↔ int
getter/setter pair
dummy5 ↔ int
getter/setter pair
dummy6 ↔ int
getter/setter pair
dummy7 ↔ int
getter/setter pair
dummy8 ↔ int
getter/setter pair
dummy9 ↔ int
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setteroverride
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownFields → UnknownFieldSet
no setterinherited

Methods

$_ensure<T>(int index) → T
For generated code only.
inherited
$_get<T>(int index, T defaultValue) → T
For generated code only.
inherited
$_getB(int index, bool defaultValue) → bool
For generated code only.
inherited
$_getBF(int index) → bool
For generated code only.
inherited
$_getI(int index, int defaultValue) → int
For generated code only.
inherited
$_getI64(int index) → Int64
For generated code only.
inherited
$_getIZ(int index) → int
For generated code only.
inherited
$_getList<T>(int index) → List<T>
For generated code only.
inherited
$_getMap<K, V>(int index) → Map<K, V>
For generated code only.
inherited
$_getN<T>(int index) → T
For generated code only.
inherited
$_getS(int index, String defaultValue) → String
For generated code only.
inherited
$_getSZ(int index) → String
For generated code only.
inherited
$_has(int index) → bool
For generated code only.
inherited
$_setBool(int index, bool value) → void
For generated code only.
inherited
$_setBytes(int index, List<int> value) → void
For generated code only.
inherited
$_setDouble(int index, double value) → void
For generated code only.
inherited
$_setFloat(int index, double value) → void
For generated code only.
inherited
$_setInt64(int index, Int64 value) → void
For generated code only.
inherited
$_setSignedInt32(int index, int value) → void
For generated code only.
inherited
$_setString(int index, String value) → void
For generated code only.
inherited
$_setUnsignedInt32(int index, int value) → void
For generated code only.
inherited
$_whichOneof(int oneofIndex) → int
inherited
addExtension(Extension extension, dynamic value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearA() → void
clearB() → void
clearC() → void
clearDummy10() → void
clearDummy11() → void
clearDummy12() → void
clearDummy13() → void
clearDummy14() → void
clearDummy15() → void
clearDummy16() → void
clearDummy17() → void
clearDummy18() → void
clearDummy19() → void
clearDummy2() → void
clearDummy20() → void
clearDummy21() → void
clearDummy22() → void
clearDummy23() → void
clearDummy24() → void
clearDummy25() → void
clearDummy26() → void
clearDummy27() → void
clearDummy28() → void
clearDummy29() → void
clearDummy30() → void
clearDummy31() → void
clearDummy32() → void
clearDummy4() → void
clearDummy5() → void
clearDummy6() → void
clearDummy7() → void
clearDummy8() → void
clearDummy9() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clone() → TestRequired
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(TestRequired)) → TestRequired
Apply updates to a copy of this message.
override
createEmptyInstance() → TestRequired
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) → Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) → List<T>
Creates List implementing a mutable repeated field.
inherited
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasA() → bool
hasB() → bool
hasC() → bool
hasDummy10() → bool
hasDummy11() → bool
hasDummy12() → bool
hasDummy13() → bool
hasDummy14() → bool
hasDummy15() → bool
hasDummy16() → bool
hasDummy17() → bool
hasDummy18() → bool
hasDummy19() → bool
hasDummy2() → bool
hasDummy20() → bool
hasDummy21() → bool
hasDummy22() → bool
hasDummy23() → bool
hasDummy24() → bool
hasDummy25() → bool
hasDummy26() → bool
hasDummy27() → bool
hasDummy28() → bool
hasDummy29() → bool
hasDummy30() → bool
hasDummy31() → bool
hasDummy32() → bool
hasDummy4() → bool
hasDummy5() → bool
hasDummy6() → bool
hasDummy7() → bool
hasDummy8() → bool
hasDummy9() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasRequiredFields() → bool
Whether the message has required fields.
inherited
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

multi → Extension<TestRequired>
final
single → Extension<TestRequired>
final

Static Methods

create() → TestRequired
createRepeated() → PbList<TestRequired>
getDefault() → TestRequired