TestServiceBase class abstract

Constructors

TestServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
bar(ServiceCall call, BarRequest request) → Future<BarResponse>
bar_Pre(ServiceCall call, Future<BarRequest> request) → Future<BarResponse>
foo(ServiceCall call, FooRequest request) → Future<FooResponse>
foo_Pre(ServiceCall call, Future<FooRequest> request) → Future<FooResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited